# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from banyanclient import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from banyanclient import schemas  # noqa: F401

from . import path

# query params
SkipSchema = schemas.StrSchema
NameSchema = schemas.StrSchema
LimitSchema = schemas.StrSchema
ClusterNameSchema = schemas.StrSchema
ClusterIdSchema = schemas.StrSchema
AddressSchema = schemas.StrSchema
OrderByDefaultcreatedAtSchema = schemas.StrSchema
OrderDefaultdescSchema = schemas.StrSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'skip': typing.Union[SkipSchema, str, ],
        'name': typing.Union[NameSchema, str, ],
        'limit': typing.Union[LimitSchema, str, ],
        'cluster_name': typing.Union[ClusterNameSchema, str, ],
        'cluster_id': typing.Union[ClusterIdSchema, str, ],
        'address': typing.Union[AddressSchema, str, ],
        'order_by(default&#x3D;created_at)': typing.Union[OrderByDefaultcreatedAtSchema, str, ],
        'order (default&#x3D;desc)': typing.Union[OrderDefaultdescSchema, str, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_skip = api_client.QueryParameter(
    name="skip",
    style=api_client.ParameterStyle.FORM,
    schema=SkipSchema,
    explode=True,
)
request_query_name = api_client.QueryParameter(
    name="name",
    style=api_client.ParameterStyle.FORM,
    schema=NameSchema,
    explode=True,
)
request_query_limit = api_client.QueryParameter(
    name="limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    explode=True,
)
request_query_cluster_name = api_client.QueryParameter(
    name="cluster_name",
    style=api_client.ParameterStyle.FORM,
    schema=ClusterNameSchema,
    explode=True,
)
request_query_cluster_id = api_client.QueryParameter(
    name="cluster_id",
    style=api_client.ParameterStyle.FORM,
    schema=ClusterIdSchema,
    explode=True,
)
request_query_address = api_client.QueryParameter(
    name="address",
    style=api_client.ParameterStyle.FORM,
    schema=AddressSchema,
    explode=True,
)
request_query_order_by_defaultcreated_at = api_client.QueryParameter(
    name="order_by(default&#x3D;created_at)",
    style=api_client.ParameterStyle.FORM,
    schema=OrderByDefaultcreatedAtSchema,
    explode=True,
)
request_query_order__defaultdesc = api_client.QueryParameter(
    name="order (default&#x3D;desc)",
    style=api_client.ParameterStyle.FORM,
    schema=OrderDefaultdescSchema,
    explode=True,
)
_auth = [
    'bearerAuthToken',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            request_id = schemas.StrSchema
            error_code = schemas.IntSchema
            error_description = schemas.StrSchema
            
            
            class data(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        
                        
                        class access_tiers(
                            schemas.ListSchema
                        ):
                        
                        
                            class MetaOapg:
                                
                                
                                class items(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        
                                        class properties:
                                            id = schemas.StrSchema
                                            name = schemas.StrSchema
                                            address = schemas.StrSchema
                                            status = schemas.StrSchema
                                            
                                            
                                            class domains(
                                                schemas.ListSchema
                                            ):
                                            
                                            
                                                class MetaOapg:
                                                    items = schemas.StrSchema
                                            
                                                def __new__(
                                                    cls,
                                                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                                    _configuration: typing.Optional[schemas.Configuration] = None,
                                                ) -> 'domains':
                                                    return super().__new__(
                                                        cls,
                                                        arg,
                                                        _configuration=_configuration,
                                                    )
                                            
                                                def __getitem__(self, i: int) -> MetaOapg.items:
                                                    return super().__getitem__(i)
                                            
                                            
                                            class netagents(
                                                schemas.ListSchema
                                            ):
                                            
                                            
                                                class MetaOapg:
                                                    
                                                    
                                                    class items(
                                                        schemas.DictSchema
                                                    ):
                                                    
                                                    
                                                        class MetaOapg:
                                                            
                                                            class properties:
                                                                Hostname = schemas.StrSchema
                                                                
                                                                
                                                                class IPs(
                                                                    schemas.ListSchema
                                                                ):
                                                                
                                                                
                                                                    class MetaOapg:
                                                                        items = schemas.StrSchema
                                                                
                                                                    def __new__(
                                                                        cls,
                                                                        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                                                    ) -> 'IPs':
                                                                        return super().__new__(
                                                                            cls,
                                                                            arg,
                                                                            _configuration=_configuration,
                                                                        )
                                                                
                                                                    def __getitem__(self, i: int) -> MetaOapg.items:
                                                                        return super().__getitem__(i)
                                                                Version = schemas.StrSchema
                                                                Visibility = schemas.IntSchema
                                                                CIDRs = schemas.StrSchema
                                                                
                                                                
                                                                class HostTags(
                                                                    schemas.DictSchema
                                                                ):
                                                                
                                                                
                                                                    class MetaOapg:
                                                                        
                                                                        class properties:
                                                                            com_banyanops_hosttag_hname = schemas.StrSchema
                                                                            com_banyanops_hosttag_site_address = schemas.StrSchema
                                                                            com_banyanops_hosttag_site_autoscale = schemas.StrSchema
                                                                            com_banyanops_hosttag_site_domain_names = schemas.StrSchema
                                                                            com_banyanops_hosttag_site_name = schemas.StrSchema
                                                                            __annotations__ = {
                                                                                "com.banyanops.hosttag.hname": com_banyanops_hosttag_hname,
                                                                                "com.banyanops.hosttag.site_address": com_banyanops_hosttag_site_address,
                                                                                "com.banyanops.hosttag.site_autoscale": com_banyanops_hosttag_site_autoscale,
                                                                                "com.banyanops.hosttag.site_domain_names": com_banyanops_hosttag_site_domain_names,
                                                                                "com.banyanops.hosttag.site_name": com_banyanops_hosttag_site_name,
                                                                            }
                                                                    
                                                                    @typing.overload
                                                                    def __getitem__(self, name: typing_extensions.Literal["com.banyanops.hosttag.hname"]) -> MetaOapg.properties.com_banyanops_hosttag_hname: ...
                                                                    
                                                                    @typing.overload
                                                                    def __getitem__(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_address"]) -> MetaOapg.properties.com_banyanops_hosttag_site_address: ...
                                                                    
                                                                    @typing.overload
                                                                    def __getitem__(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_autoscale"]) -> MetaOapg.properties.com_banyanops_hosttag_site_autoscale: ...
                                                                    
                                                                    @typing.overload
                                                                    def __getitem__(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_domain_names"]) -> MetaOapg.properties.com_banyanops_hosttag_site_domain_names: ...
                                                                    
                                                                    @typing.overload
                                                                    def __getitem__(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_name"]) -> MetaOapg.properties.com_banyanops_hosttag_site_name: ...
                                                                    
                                                                    @typing.overload
                                                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                                    
                                                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["com.banyanops.hosttag.hname", "com.banyanops.hosttag.site_address", "com.banyanops.hosttag.site_autoscale", "com.banyanops.hosttag.site_domain_names", "com.banyanops.hosttag.site_name", ], str]):
                                                                        # dict_instance[name] accessor
                                                                        return super().__getitem__(name)
                                                                    
                                                                    
                                                                    @typing.overload
                                                                    def get_item_oapg(self, name: typing_extensions.Literal["com.banyanops.hosttag.hname"]) -> typing.Union[MetaOapg.properties.com_banyanops_hosttag_hname, schemas.Unset]: ...
                                                                    
                                                                    @typing.overload
                                                                    def get_item_oapg(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_address"]) -> typing.Union[MetaOapg.properties.com_banyanops_hosttag_site_address, schemas.Unset]: ...
                                                                    
                                                                    @typing.overload
                                                                    def get_item_oapg(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_autoscale"]) -> typing.Union[MetaOapg.properties.com_banyanops_hosttag_site_autoscale, schemas.Unset]: ...
                                                                    
                                                                    @typing.overload
                                                                    def get_item_oapg(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_domain_names"]) -> typing.Union[MetaOapg.properties.com_banyanops_hosttag_site_domain_names, schemas.Unset]: ...
                                                                    
                                                                    @typing.overload
                                                                    def get_item_oapg(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_name"]) -> typing.Union[MetaOapg.properties.com_banyanops_hosttag_site_name, schemas.Unset]: ...
                                                                    
                                                                    @typing.overload
                                                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                                    
                                                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["com.banyanops.hosttag.hname", "com.banyanops.hosttag.site_address", "com.banyanops.hosttag.site_autoscale", "com.banyanops.hosttag.site_domain_names", "com.banyanops.hosttag.site_name", ], str]):
                                                                        return super().get_item_oapg(name)
                                                                    
                                                                
                                                                    def __new__(
                                                                        cls,
                                                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                                    ) -> 'HostTags':
                                                                        return super().__new__(
                                                                            cls,
                                                                            *args,
                                                                            _configuration=_configuration,
                                                                            **kwargs,
                                                                        )
                                                                Uname = schemas.StrSchema
                                                                ClusterID = schemas.StrSchema
                                                                LastActivityAt = schemas.StrSchema
                                                                CreatedAt = schemas.StrSchema
                                                                Status = schemas.StrSchema
                                                                __annotations__ = {
                                                                    "Hostname": Hostname,
                                                                    "IPs": IPs,
                                                                    "Version": Version,
                                                                    "Visibility": Visibility,
                                                                    "CIDRs": CIDRs,
                                                                    "HostTags": HostTags,
                                                                    "Uname": Uname,
                                                                    "ClusterID": ClusterID,
                                                                    "LastActivityAt": LastActivityAt,
                                                                    "CreatedAt": CreatedAt,
                                                                    "Status": Status,
                                                                }
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["Hostname"]) -> MetaOapg.properties.Hostname: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["IPs"]) -> MetaOapg.properties.IPs: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["Version"]) -> MetaOapg.properties.Version: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["Visibility"]) -> MetaOapg.properties.Visibility: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["CIDRs"]) -> MetaOapg.properties.CIDRs: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["HostTags"]) -> MetaOapg.properties.HostTags: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["Uname"]) -> MetaOapg.properties.Uname: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["ClusterID"]) -> MetaOapg.properties.ClusterID: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["LastActivityAt"]) -> MetaOapg.properties.LastActivityAt: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["CreatedAt"]) -> MetaOapg.properties.CreatedAt: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: typing_extensions.Literal["Status"]) -> MetaOapg.properties.Status: ...
                                                        
                                                        @typing.overload
                                                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                        
                                                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["Hostname", "IPs", "Version", "Visibility", "CIDRs", "HostTags", "Uname", "ClusterID", "LastActivityAt", "CreatedAt", "Status", ], str]):
                                                            # dict_instance[name] accessor
                                                            return super().__getitem__(name)
                                                        
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["Hostname"]) -> typing.Union[MetaOapg.properties.Hostname, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["IPs"]) -> typing.Union[MetaOapg.properties.IPs, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["Version"]) -> typing.Union[MetaOapg.properties.Version, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["Visibility"]) -> typing.Union[MetaOapg.properties.Visibility, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["CIDRs"]) -> typing.Union[MetaOapg.properties.CIDRs, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["HostTags"]) -> typing.Union[MetaOapg.properties.HostTags, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["Uname"]) -> typing.Union[MetaOapg.properties.Uname, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["ClusterID"]) -> typing.Union[MetaOapg.properties.ClusterID, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["LastActivityAt"]) -> typing.Union[MetaOapg.properties.LastActivityAt, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["CreatedAt"]) -> typing.Union[MetaOapg.properties.CreatedAt, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: typing_extensions.Literal["Status"]) -> typing.Union[MetaOapg.properties.Status, schemas.Unset]: ...
                                                        
                                                        @typing.overload
                                                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                        
                                                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["Hostname", "IPs", "Version", "Visibility", "CIDRs", "HostTags", "Uname", "ClusterID", "LastActivityAt", "CreatedAt", "Status", ], str]):
                                                            return super().get_item_oapg(name)
                                                        
                                                    
                                                        def __new__(
                                                            cls,
                                                            *args: typing.Union[dict, frozendict.frozendict, ],
                                                            Hostname: typing.Union[MetaOapg.properties.Hostname, str, schemas.Unset] = schemas.unset,
                                                            IPs: typing.Union[MetaOapg.properties.IPs, list, tuple, schemas.Unset] = schemas.unset,
                                                            Version: typing.Union[MetaOapg.properties.Version, str, schemas.Unset] = schemas.unset,
                                                            Visibility: typing.Union[MetaOapg.properties.Visibility, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                            CIDRs: typing.Union[MetaOapg.properties.CIDRs, str, schemas.Unset] = schemas.unset,
                                                            HostTags: typing.Union[MetaOapg.properties.HostTags, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                                                            Uname: typing.Union[MetaOapg.properties.Uname, str, schemas.Unset] = schemas.unset,
                                                            ClusterID: typing.Union[MetaOapg.properties.ClusterID, str, schemas.Unset] = schemas.unset,
                                                            LastActivityAt: typing.Union[MetaOapg.properties.LastActivityAt, str, schemas.Unset] = schemas.unset,
                                                            CreatedAt: typing.Union[MetaOapg.properties.CreatedAt, str, schemas.Unset] = schemas.unset,
                                                            Status: typing.Union[MetaOapg.properties.Status, str, schemas.Unset] = schemas.unset,
                                                            _configuration: typing.Optional[schemas.Configuration] = None,
                                                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                        ) -> 'items':
                                                            return super().__new__(
                                                                cls,
                                                                *args,
                                                                Hostname=Hostname,
                                                                IPs=IPs,
                                                                Version=Version,
                                                                Visibility=Visibility,
                                                                CIDRs=CIDRs,
                                                                HostTags=HostTags,
                                                                Uname=Uname,
                                                                ClusterID=ClusterID,
                                                                LastActivityAt=LastActivityAt,
                                                                CreatedAt=CreatedAt,
                                                                Status=Status,
                                                                _configuration=_configuration,
                                                                **kwargs,
                                                            )
                                            
                                                def __new__(
                                                    cls,
                                                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                                                    _configuration: typing.Optional[schemas.Configuration] = None,
                                                ) -> 'netagents':
                                                    return super().__new__(
                                                        cls,
                                                        arg,
                                                        _configuration=_configuration,
                                                    )
                                            
                                                def __getitem__(self, i: int) -> MetaOapg.items:
                                                    return super().__getitem__(i)
                                            Hostname = schemas.StrSchema
                                            
                                            
                                            class IPs(
                                                schemas.ListSchema
                                            ):
                                            
                                            
                                                class MetaOapg:
                                                    items = schemas.StrSchema
                                            
                                                def __new__(
                                                    cls,
                                                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                                    _configuration: typing.Optional[schemas.Configuration] = None,
                                                ) -> 'IPs':
                                                    return super().__new__(
                                                        cls,
                                                        arg,
                                                        _configuration=_configuration,
                                                    )
                                            
                                                def __getitem__(self, i: int) -> MetaOapg.items:
                                                    return super().__getitem__(i)
                                            Version = schemas.StrSchema
                                            Visibility = schemas.IntSchema
                                            CIDRs = schemas.StrSchema
                                            
                                            
                                            class HostTags(
                                                schemas.DictSchema
                                            ):
                                            
                                            
                                                class MetaOapg:
                                                    
                                                    class properties:
                                                        com_banyanops_hosttag_hname = schemas.StrSchema
                                                        com_banyanops_hosttag_site_address = schemas.StrSchema
                                                        com_banyanops_hosttag_site_autoscale = schemas.StrSchema
                                                        com_banyanops_hosttag_site_domain_names = schemas.StrSchema
                                                        com_banyanops_hosttag_site_name = schemas.StrSchema
                                                        Uname = schemas.StrSchema
                                                        ClusterID = schemas.StrSchema
                                                        LastActivityAt = schemas.StrSchema
                                                        CreatedAt = schemas.StrSchema
                                                        Status = schemas.StrSchema
                                                        __annotations__ = {
                                                            "com.banyanops.hosttag.hname": com_banyanops_hosttag_hname,
                                                            "com.banyanops.hosttag.site_address": com_banyanops_hosttag_site_address,
                                                            "com.banyanops.hosttag.site_autoscale": com_banyanops_hosttag_site_autoscale,
                                                            "com.banyanops.hosttag.site_domain_names": com_banyanops_hosttag_site_domain_names,
                                                            "com.banyanops.hosttag.site_name": com_banyanops_hosttag_site_name,
                                                            "Uname": Uname,
                                                            "ClusterID": ClusterID,
                                                            "LastActivityAt": LastActivityAt,
                                                            "CreatedAt": CreatedAt,
                                                            "Status": Status,
                                                        }
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["com.banyanops.hosttag.hname"]) -> MetaOapg.properties.com_banyanops_hosttag_hname: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_address"]) -> MetaOapg.properties.com_banyanops_hosttag_site_address: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_autoscale"]) -> MetaOapg.properties.com_banyanops_hosttag_site_autoscale: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_domain_names"]) -> MetaOapg.properties.com_banyanops_hosttag_site_domain_names: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_name"]) -> MetaOapg.properties.com_banyanops_hosttag_site_name: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["Uname"]) -> MetaOapg.properties.Uname: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["ClusterID"]) -> MetaOapg.properties.ClusterID: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["LastActivityAt"]) -> MetaOapg.properties.LastActivityAt: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["CreatedAt"]) -> MetaOapg.properties.CreatedAt: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["Status"]) -> MetaOapg.properties.Status: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                
                                                def __getitem__(self, name: typing.Union[typing_extensions.Literal["com.banyanops.hosttag.hname", "com.banyanops.hosttag.site_address", "com.banyanops.hosttag.site_autoscale", "com.banyanops.hosttag.site_domain_names", "com.banyanops.hosttag.site_name", "Uname", "ClusterID", "LastActivityAt", "CreatedAt", "Status", ], str]):
                                                    # dict_instance[name] accessor
                                                    return super().__getitem__(name)
                                                
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["com.banyanops.hosttag.hname"]) -> typing.Union[MetaOapg.properties.com_banyanops_hosttag_hname, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_address"]) -> typing.Union[MetaOapg.properties.com_banyanops_hosttag_site_address, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_autoscale"]) -> typing.Union[MetaOapg.properties.com_banyanops_hosttag_site_autoscale, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_domain_names"]) -> typing.Union[MetaOapg.properties.com_banyanops_hosttag_site_domain_names, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["com.banyanops.hosttag.site_name"]) -> typing.Union[MetaOapg.properties.com_banyanops_hosttag_site_name, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["Uname"]) -> typing.Union[MetaOapg.properties.Uname, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["ClusterID"]) -> typing.Union[MetaOapg.properties.ClusterID, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["LastActivityAt"]) -> typing.Union[MetaOapg.properties.LastActivityAt, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["CreatedAt"]) -> typing.Union[MetaOapg.properties.CreatedAt, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["Status"]) -> typing.Union[MetaOapg.properties.Status, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                
                                                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["com.banyanops.hosttag.hname", "com.banyanops.hosttag.site_address", "com.banyanops.hosttag.site_autoscale", "com.banyanops.hosttag.site_domain_names", "com.banyanops.hosttag.site_name", "Uname", "ClusterID", "LastActivityAt", "CreatedAt", "Status", ], str]):
                                                    return super().get_item_oapg(name)
                                                
                                            
                                                def __new__(
                                                    cls,
                                                    *args: typing.Union[dict, frozendict.frozendict, ],
                                                    Uname: typing.Union[MetaOapg.properties.Uname, str, schemas.Unset] = schemas.unset,
                                                    ClusterID: typing.Union[MetaOapg.properties.ClusterID, str, schemas.Unset] = schemas.unset,
                                                    LastActivityAt: typing.Union[MetaOapg.properties.LastActivityAt, str, schemas.Unset] = schemas.unset,
                                                    CreatedAt: typing.Union[MetaOapg.properties.CreatedAt, str, schemas.Unset] = schemas.unset,
                                                    Status: typing.Union[MetaOapg.properties.Status, str, schemas.Unset] = schemas.unset,
                                                    _configuration: typing.Optional[schemas.Configuration] = None,
                                                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                ) -> 'HostTags':
                                                    return super().__new__(
                                                        cls,
                                                        *args,
                                                        Uname=Uname,
                                                        ClusterID=ClusterID,
                                                        LastActivityAt=LastActivityAt,
                                                        CreatedAt=CreatedAt,
                                                        Status=Status,
                                                        _configuration=_configuration,
                                                        **kwargs,
                                                    )
                                            
                                            
                                            class tunnel_satellite(
                                                schemas.DictSchema
                                            ):
                                            
                                            
                                                class MetaOapg:
                                                    
                                                    class properties:
                                                        id = schemas.StrSchema
                                                        org_id = schemas.StrSchema
                                                        access_tier_id = schemas.StrSchema
                                                        tunnel_peer_type = schemas.StrSchema
                                                        dns_search_domains = schemas.StrSchema
                                                        udp_port_number = schemas.IntSchema
                                                        tunnel_ip_address = schemas.StrSchema
                                                        wireguard_public_key = schemas.StrSchema
                                                        dns_enabled = schemas.IntSchema
                                                        keepalive = schemas.IntSchema
                                                        created_at = schemas.IntSchema
                                                        updated_at = schemas.IntSchema
                                                        
                                                        
                                                        class cidrs(
                                                            schemas.ListSchema
                                                        ):
                                                        
                                                        
                                                            class MetaOapg:
                                                                items = schemas.StrSchema
                                                        
                                                            def __new__(
                                                                cls,
                                                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                                            ) -> 'cidrs':
                                                                return super().__new__(
                                                                    cls,
                                                                    arg,
                                                                    _configuration=_configuration,
                                                                )
                                                        
                                                            def __getitem__(self, i: int) -> MetaOapg.items:
                                                                return super().__getitem__(i)
                                                        
                                                        
                                                        class domains(
                                                            schemas.ListSchema
                                                        ):
                                                        
                                                        
                                                            class MetaOapg:
                                                                items = schemas.StrSchema
                                                        
                                                            def __new__(
                                                                cls,
                                                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                                            ) -> 'domains':
                                                                return super().__new__(
                                                                    cls,
                                                                    arg,
                                                                    _configuration=_configuration,
                                                                )
                                                        
                                                            def __getitem__(self, i: int) -> MetaOapg.items:
                                                                return super().__getitem__(i)
                                                        client_cidr_range = schemas.StrSchema
                                                        __annotations__ = {
                                                            "id": id,
                                                            "org_id": org_id,
                                                            "access_tier_id": access_tier_id,
                                                            "tunnel_peer_type": tunnel_peer_type,
                                                            "dns_search_domains": dns_search_domains,
                                                            "udp_port_number": udp_port_number,
                                                            "tunnel_ip_address": tunnel_ip_address,
                                                            "wireguard_public_key": wireguard_public_key,
                                                            "dns_enabled": dns_enabled,
                                                            "keepalive": keepalive,
                                                            "created_at": created_at,
                                                            "updated_at": updated_at,
                                                            "cidrs": cidrs,
                                                            "domains": domains,
                                                            "client_cidr_range": client_cidr_range,
                                                        }
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["org_id"]) -> MetaOapg.properties.org_id: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["access_tier_id"]) -> MetaOapg.properties.access_tier_id: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["tunnel_peer_type"]) -> MetaOapg.properties.tunnel_peer_type: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["dns_search_domains"]) -> MetaOapg.properties.dns_search_domains: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["udp_port_number"]) -> MetaOapg.properties.udp_port_number: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["tunnel_ip_address"]) -> MetaOapg.properties.tunnel_ip_address: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["wireguard_public_key"]) -> MetaOapg.properties.wireguard_public_key: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["dns_enabled"]) -> MetaOapg.properties.dns_enabled: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["keepalive"]) -> MetaOapg.properties.keepalive: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["cidrs"]) -> MetaOapg.properties.cidrs: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["domains"]) -> MetaOapg.properties.domains: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["client_cidr_range"]) -> MetaOapg.properties.client_cidr_range: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                
                                                def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "org_id", "access_tier_id", "tunnel_peer_type", "dns_search_domains", "udp_port_number", "tunnel_ip_address", "wireguard_public_key", "dns_enabled", "keepalive", "created_at", "updated_at", "cidrs", "domains", "client_cidr_range", ], str]):
                                                    # dict_instance[name] accessor
                                                    return super().__getitem__(name)
                                                
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["org_id"]) -> typing.Union[MetaOapg.properties.org_id, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["access_tier_id"]) -> typing.Union[MetaOapg.properties.access_tier_id, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["tunnel_peer_type"]) -> typing.Union[MetaOapg.properties.tunnel_peer_type, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["dns_search_domains"]) -> typing.Union[MetaOapg.properties.dns_search_domains, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["udp_port_number"]) -> typing.Union[MetaOapg.properties.udp_port_number, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["tunnel_ip_address"]) -> typing.Union[MetaOapg.properties.tunnel_ip_address, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["wireguard_public_key"]) -> typing.Union[MetaOapg.properties.wireguard_public_key, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["dns_enabled"]) -> typing.Union[MetaOapg.properties.dns_enabled, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["keepalive"]) -> typing.Union[MetaOapg.properties.keepalive, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["cidrs"]) -> typing.Union[MetaOapg.properties.cidrs, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["domains"]) -> typing.Union[MetaOapg.properties.domains, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["client_cidr_range"]) -> typing.Union[MetaOapg.properties.client_cidr_range, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                
                                                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "org_id", "access_tier_id", "tunnel_peer_type", "dns_search_domains", "udp_port_number", "tunnel_ip_address", "wireguard_public_key", "dns_enabled", "keepalive", "created_at", "updated_at", "cidrs", "domains", "client_cidr_range", ], str]):
                                                    return super().get_item_oapg(name)
                                                
                                            
                                                def __new__(
                                                    cls,
                                                    *args: typing.Union[dict, frozendict.frozendict, ],
                                                    id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
                                                    org_id: typing.Union[MetaOapg.properties.org_id, str, schemas.Unset] = schemas.unset,
                                                    access_tier_id: typing.Union[MetaOapg.properties.access_tier_id, str, schemas.Unset] = schemas.unset,
                                                    tunnel_peer_type: typing.Union[MetaOapg.properties.tunnel_peer_type, str, schemas.Unset] = schemas.unset,
                                                    dns_search_domains: typing.Union[MetaOapg.properties.dns_search_domains, str, schemas.Unset] = schemas.unset,
                                                    udp_port_number: typing.Union[MetaOapg.properties.udp_port_number, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    tunnel_ip_address: typing.Union[MetaOapg.properties.tunnel_ip_address, str, schemas.Unset] = schemas.unset,
                                                    wireguard_public_key: typing.Union[MetaOapg.properties.wireguard_public_key, str, schemas.Unset] = schemas.unset,
                                                    dns_enabled: typing.Union[MetaOapg.properties.dns_enabled, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    keepalive: typing.Union[MetaOapg.properties.keepalive, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    created_at: typing.Union[MetaOapg.properties.created_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    updated_at: typing.Union[MetaOapg.properties.updated_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    cidrs: typing.Union[MetaOapg.properties.cidrs, list, tuple, schemas.Unset] = schemas.unset,
                                                    domains: typing.Union[MetaOapg.properties.domains, list, tuple, schemas.Unset] = schemas.unset,
                                                    client_cidr_range: typing.Union[MetaOapg.properties.client_cidr_range, str, schemas.Unset] = schemas.unset,
                                                    _configuration: typing.Optional[schemas.Configuration] = None,
                                                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                ) -> 'tunnel_satellite':
                                                    return super().__new__(
                                                        cls,
                                                        *args,
                                                        id=id,
                                                        org_id=org_id,
                                                        access_tier_id=access_tier_id,
                                                        tunnel_peer_type=tunnel_peer_type,
                                                        dns_search_domains=dns_search_domains,
                                                        udp_port_number=udp_port_number,
                                                        tunnel_ip_address=tunnel_ip_address,
                                                        wireguard_public_key=wireguard_public_key,
                                                        dns_enabled=dns_enabled,
                                                        keepalive=keepalive,
                                                        created_at=created_at,
                                                        updated_at=updated_at,
                                                        cidrs=cidrs,
                                                        domains=domains,
                                                        client_cidr_range=client_cidr_range,
                                                        _configuration=_configuration,
                                                        **kwargs,
                                                    )
                                            
                                            
                                            class tunnel_enduser(
                                                schemas.DictSchema
                                            ):
                                            
                                            
                                                class MetaOapg:
                                                    
                                                    class properties:
                                                        id = schemas.StrSchema
                                                        org_id = schemas.StrSchema
                                                        access_tier_id = schemas.StrSchema
                                                        tunnel_peer_type = schemas.StrSchema
                                                        dns_search_domains = schemas.StrSchema
                                                        udp_port_number = schemas.IntSchema
                                                        tunnel_ip_address = schemas.StrSchema
                                                        wireguard_public_key = schemas.StrSchema
                                                        dns_enabled = schemas.IntSchema
                                                        keepalive = schemas.IntSchema
                                                        created_at = schemas.IntSchema
                                                        updated_at = schemas.IntSchema
                                                        
                                                        
                                                        class cidrs(
                                                            schemas.ListSchema
                                                        ):
                                                        
                                                        
                                                            class MetaOapg:
                                                                items = schemas.StrSchema
                                                        
                                                            def __new__(
                                                                cls,
                                                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                                            ) -> 'cidrs':
                                                                return super().__new__(
                                                                    cls,
                                                                    arg,
                                                                    _configuration=_configuration,
                                                                )
                                                        
                                                            def __getitem__(self, i: int) -> MetaOapg.items:
                                                                return super().__getitem__(i)
                                                        
                                                        
                                                        class domains(
                                                            schemas.ListSchema
                                                        ):
                                                        
                                                        
                                                            class MetaOapg:
                                                                items = schemas.StrSchema
                                                        
                                                            def __new__(
                                                                cls,
                                                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                                            ) -> 'domains':
                                                                return super().__new__(
                                                                    cls,
                                                                    arg,
                                                                    _configuration=_configuration,
                                                                )
                                                        
                                                            def __getitem__(self, i: int) -> MetaOapg.items:
                                                                return super().__getitem__(i)
                                                        client_cidr_range = schemas.StrSchema
                                                        __annotations__ = {
                                                            "id": id,
                                                            "org_id": org_id,
                                                            "access_tier_id": access_tier_id,
                                                            "tunnel_peer_type": tunnel_peer_type,
                                                            "dns_search_domains": dns_search_domains,
                                                            "udp_port_number": udp_port_number,
                                                            "tunnel_ip_address": tunnel_ip_address,
                                                            "wireguard_public_key": wireguard_public_key,
                                                            "dns_enabled": dns_enabled,
                                                            "keepalive": keepalive,
                                                            "created_at": created_at,
                                                            "updated_at": updated_at,
                                                            "cidrs": cidrs,
                                                            "domains": domains,
                                                            "client_cidr_range": client_cidr_range,
                                                        }
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["org_id"]) -> MetaOapg.properties.org_id: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["access_tier_id"]) -> MetaOapg.properties.access_tier_id: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["tunnel_peer_type"]) -> MetaOapg.properties.tunnel_peer_type: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["dns_search_domains"]) -> MetaOapg.properties.dns_search_domains: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["udp_port_number"]) -> MetaOapg.properties.udp_port_number: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["tunnel_ip_address"]) -> MetaOapg.properties.tunnel_ip_address: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["wireguard_public_key"]) -> MetaOapg.properties.wireguard_public_key: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["dns_enabled"]) -> MetaOapg.properties.dns_enabled: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["keepalive"]) -> MetaOapg.properties.keepalive: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["cidrs"]) -> MetaOapg.properties.cidrs: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["domains"]) -> MetaOapg.properties.domains: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: typing_extensions.Literal["client_cidr_range"]) -> MetaOapg.properties.client_cidr_range: ...
                                                
                                                @typing.overload
                                                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                                
                                                def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "org_id", "access_tier_id", "tunnel_peer_type", "dns_search_domains", "udp_port_number", "tunnel_ip_address", "wireguard_public_key", "dns_enabled", "keepalive", "created_at", "updated_at", "cidrs", "domains", "client_cidr_range", ], str]):
                                                    # dict_instance[name] accessor
                                                    return super().__getitem__(name)
                                                
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["org_id"]) -> typing.Union[MetaOapg.properties.org_id, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["access_tier_id"]) -> typing.Union[MetaOapg.properties.access_tier_id, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["tunnel_peer_type"]) -> typing.Union[MetaOapg.properties.tunnel_peer_type, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["dns_search_domains"]) -> typing.Union[MetaOapg.properties.dns_search_domains, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["udp_port_number"]) -> typing.Union[MetaOapg.properties.udp_port_number, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["tunnel_ip_address"]) -> typing.Union[MetaOapg.properties.tunnel_ip_address, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["wireguard_public_key"]) -> typing.Union[MetaOapg.properties.wireguard_public_key, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["dns_enabled"]) -> typing.Union[MetaOapg.properties.dns_enabled, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["keepalive"]) -> typing.Union[MetaOapg.properties.keepalive, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["cidrs"]) -> typing.Union[MetaOapg.properties.cidrs, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["domains"]) -> typing.Union[MetaOapg.properties.domains, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: typing_extensions.Literal["client_cidr_range"]) -> typing.Union[MetaOapg.properties.client_cidr_range, schemas.Unset]: ...
                                                
                                                @typing.overload
                                                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                                
                                                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "org_id", "access_tier_id", "tunnel_peer_type", "dns_search_domains", "udp_port_number", "tunnel_ip_address", "wireguard_public_key", "dns_enabled", "keepalive", "created_at", "updated_at", "cidrs", "domains", "client_cidr_range", ], str]):
                                                    return super().get_item_oapg(name)
                                                
                                            
                                                def __new__(
                                                    cls,
                                                    *args: typing.Union[dict, frozendict.frozendict, ],
                                                    id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
                                                    org_id: typing.Union[MetaOapg.properties.org_id, str, schemas.Unset] = schemas.unset,
                                                    access_tier_id: typing.Union[MetaOapg.properties.access_tier_id, str, schemas.Unset] = schemas.unset,
                                                    tunnel_peer_type: typing.Union[MetaOapg.properties.tunnel_peer_type, str, schemas.Unset] = schemas.unset,
                                                    dns_search_domains: typing.Union[MetaOapg.properties.dns_search_domains, str, schemas.Unset] = schemas.unset,
                                                    udp_port_number: typing.Union[MetaOapg.properties.udp_port_number, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    tunnel_ip_address: typing.Union[MetaOapg.properties.tunnel_ip_address, str, schemas.Unset] = schemas.unset,
                                                    wireguard_public_key: typing.Union[MetaOapg.properties.wireguard_public_key, str, schemas.Unset] = schemas.unset,
                                                    dns_enabled: typing.Union[MetaOapg.properties.dns_enabled, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    keepalive: typing.Union[MetaOapg.properties.keepalive, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    created_at: typing.Union[MetaOapg.properties.created_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    updated_at: typing.Union[MetaOapg.properties.updated_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                                    cidrs: typing.Union[MetaOapg.properties.cidrs, list, tuple, schemas.Unset] = schemas.unset,
                                                    domains: typing.Union[MetaOapg.properties.domains, list, tuple, schemas.Unset] = schemas.unset,
                                                    client_cidr_range: typing.Union[MetaOapg.properties.client_cidr_range, str, schemas.Unset] = schemas.unset,
                                                    _configuration: typing.Optional[schemas.Configuration] = None,
                                                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                                ) -> 'tunnel_enduser':
                                                    return super().__new__(
                                                        cls,
                                                        *args,
                                                        id=id,
                                                        org_id=org_id,
                                                        access_tier_id=access_tier_id,
                                                        tunnel_peer_type=tunnel_peer_type,
                                                        dns_search_domains=dns_search_domains,
                                                        udp_port_number=udp_port_number,
                                                        tunnel_ip_address=tunnel_ip_address,
                                                        wireguard_public_key=wireguard_public_key,
                                                        dns_enabled=dns_enabled,
                                                        keepalive=keepalive,
                                                        created_at=created_at,
                                                        updated_at=updated_at,
                                                        cidrs=cidrs,
                                                        domains=domains,
                                                        client_cidr_range=client_cidr_range,
                                                        _configuration=_configuration,
                                                        **kwargs,
                                                    )
                                            created_at = schemas.IntSchema
                                            created_by = schemas.StrSchema
                                            updated_at = schemas.IntSchema
                                            updated_by = schemas.StrSchema
                                            __annotations__ = {
                                                "id": id,
                                                "name": name,
                                                "address": address,
                                                "status": status,
                                                "domains": domains,
                                                "netagents": netagents,
                                                "Hostname": Hostname,
                                                "IPs": IPs,
                                                "Version": Version,
                                                "Visibility": Visibility,
                                                "CIDRs": CIDRs,
                                                "HostTags": HostTags,
                                                "tunnel_satellite": tunnel_satellite,
                                                "tunnel_enduser": tunnel_enduser,
                                                "created_at": created_at,
                                                "created_by": created_by,
                                                "updated_at": updated_at,
                                                "updated_by": updated_by,
                                            }
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["domains"]) -> MetaOapg.properties.domains: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["netagents"]) -> MetaOapg.properties.netagents: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Hostname"]) -> MetaOapg.properties.Hostname: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["IPs"]) -> MetaOapg.properties.IPs: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Version"]) -> MetaOapg.properties.Version: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Visibility"]) -> MetaOapg.properties.Visibility: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["CIDRs"]) -> MetaOapg.properties.CIDRs: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["HostTags"]) -> MetaOapg.properties.HostTags: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["tunnel_satellite"]) -> MetaOapg.properties.tunnel_satellite: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["tunnel_enduser"]) -> MetaOapg.properties.tunnel_enduser: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["created_by"]) -> MetaOapg.properties.created_by: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["updated_by"]) -> MetaOapg.properties.updated_by: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "name", "address", "status", "domains", "netagents", "Hostname", "IPs", "Version", "Visibility", "CIDRs", "HostTags", "tunnel_satellite", "tunnel_enduser", "created_at", "created_by", "updated_at", "updated_by", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> typing.Union[MetaOapg.properties.address, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["domains"]) -> typing.Union[MetaOapg.properties.domains, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["netagents"]) -> typing.Union[MetaOapg.properties.netagents, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Hostname"]) -> typing.Union[MetaOapg.properties.Hostname, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["IPs"]) -> typing.Union[MetaOapg.properties.IPs, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Version"]) -> typing.Union[MetaOapg.properties.Version, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Visibility"]) -> typing.Union[MetaOapg.properties.Visibility, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["CIDRs"]) -> typing.Union[MetaOapg.properties.CIDRs, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["HostTags"]) -> typing.Union[MetaOapg.properties.HostTags, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["tunnel_satellite"]) -> typing.Union[MetaOapg.properties.tunnel_satellite, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["tunnel_enduser"]) -> typing.Union[MetaOapg.properties.tunnel_enduser, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["created_by"]) -> typing.Union[MetaOapg.properties.created_by, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["updated_by"]) -> typing.Union[MetaOapg.properties.updated_by, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "name", "address", "status", "domains", "netagents", "Hostname", "IPs", "Version", "Visibility", "CIDRs", "HostTags", "tunnel_satellite", "tunnel_enduser", "created_at", "created_by", "updated_at", "updated_by", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                        id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
                                        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                                        address: typing.Union[MetaOapg.properties.address, str, schemas.Unset] = schemas.unset,
                                        status: typing.Union[MetaOapg.properties.status, str, schemas.Unset] = schemas.unset,
                                        domains: typing.Union[MetaOapg.properties.domains, list, tuple, schemas.Unset] = schemas.unset,
                                        netagents: typing.Union[MetaOapg.properties.netagents, list, tuple, schemas.Unset] = schemas.unset,
                                        Hostname: typing.Union[MetaOapg.properties.Hostname, str, schemas.Unset] = schemas.unset,
                                        IPs: typing.Union[MetaOapg.properties.IPs, list, tuple, schemas.Unset] = schemas.unset,
                                        Version: typing.Union[MetaOapg.properties.Version, str, schemas.Unset] = schemas.unset,
                                        Visibility: typing.Union[MetaOapg.properties.Visibility, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        CIDRs: typing.Union[MetaOapg.properties.CIDRs, str, schemas.Unset] = schemas.unset,
                                        HostTags: typing.Union[MetaOapg.properties.HostTags, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                                        tunnel_satellite: typing.Union[MetaOapg.properties.tunnel_satellite, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                                        tunnel_enduser: typing.Union[MetaOapg.properties.tunnel_enduser, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                                        created_at: typing.Union[MetaOapg.properties.created_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        created_by: typing.Union[MetaOapg.properties.created_by, str, schemas.Unset] = schemas.unset,
                                        updated_at: typing.Union[MetaOapg.properties.updated_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        updated_by: typing.Union[MetaOapg.properties.updated_by, str, schemas.Unset] = schemas.unset,
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'items':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            id=id,
                                            name=name,
                                            address=address,
                                            status=status,
                                            domains=domains,
                                            netagents=netagents,
                                            Hostname=Hostname,
                                            IPs=IPs,
                                            Version=Version,
                                            Visibility=Visibility,
                                            CIDRs=CIDRs,
                                            HostTags=HostTags,
                                            tunnel_satellite=tunnel_satellite,
                                            tunnel_enduser=tunnel_enduser,
                                            created_at=created_at,
                                            created_by=created_by,
                                            updated_at=updated_at,
                                            updated_by=updated_by,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                        
                            def __new__(
                                cls,
                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                                _configuration: typing.Optional[schemas.Configuration] = None,
                            ) -> 'access_tiers':
                                return super().__new__(
                                    cls,
                                    arg,
                                    _configuration=_configuration,
                                )
                        
                            def __getitem__(self, i: int) -> MetaOapg.items:
                                return super().__getitem__(i)
                        count = schemas.IntSchema
                        __annotations__ = {
                            "access_tiers": access_tiers,
                            "count": count,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["access_tiers"]) -> MetaOapg.properties.access_tiers: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["count"]) -> MetaOapg.properties.count: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["access_tiers", "count", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["access_tiers"]) -> typing.Union[MetaOapg.properties.access_tiers, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["count"]) -> typing.Union[MetaOapg.properties.count, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["access_tiers", "count", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    access_tiers: typing.Union[MetaOapg.properties.access_tiers, list, tuple, schemas.Unset] = schemas.unset,
                    count: typing.Union[MetaOapg.properties.count, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'data':
                    return super().__new__(
                        cls,
                        *args,
                        access_tiers=access_tiers,
                        count=count,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "request_id": request_id,
                "error_code": error_code,
                "error_description": error_description,
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["request_id"]) -> MetaOapg.properties.request_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_code"]) -> MetaOapg.properties.error_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_description"]) -> MetaOapg.properties.error_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["request_id"]) -> typing.Union[MetaOapg.properties.request_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_code"]) -> typing.Union[MetaOapg.properties.error_code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_description"]) -> typing.Union[MetaOapg.properties.error_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        request_id: typing.Union[MetaOapg.properties.request_id, str, schemas.Unset] = schemas.unset,
        error_code: typing.Union[MetaOapg.properties.error_code, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        error_description: typing.Union[MetaOapg.properties.error_description, str, schemas.Unset] = schemas.unset,
        data: typing.Union[MetaOapg.properties.data, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            request_id=request_id,
            error_code=error_code,
            error_description=error_description,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
)


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
)


class SchemaFor500ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            request_id = schemas.StrSchema
            error_code = schemas.IntSchema
            error_description = schemas.StrSchema
            data = schemas.IntSchema
            __annotations__ = {
                "request_id": request_id,
                "error_code": error_code,
                "error_description": error_description,
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["request_id"]) -> MetaOapg.properties.request_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_code"]) -> MetaOapg.properties.error_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_description"]) -> MetaOapg.properties.error_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["request_id"]) -> typing.Union[MetaOapg.properties.request_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_code"]) -> typing.Union[MetaOapg.properties.error_code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_description"]) -> typing.Union[MetaOapg.properties.error_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        request_id: typing.Union[MetaOapg.properties.request_id, str, schemas.Unset] = schemas.unset,
        error_code: typing.Union[MetaOapg.properties.error_code, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        error_description: typing.Union[MetaOapg.properties.error_description, str, schemas.Unset] = schemas.unset,
        data: typing.Union[MetaOapg.properties.data, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor500ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            request_id=request_id,
            error_code=error_code,
            error_description=error_description,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor500ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor500ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '401': _response_for_401,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):

    def _v2_access_tier_get_oapg(
        self: api_client.Api,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
         List Access Tier(s) of an organization
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_skip,
            request_query_name,
            request_query_limit,
            request_query_cluster_name,
            request_query_cluster_id,
            request_query_address,
            request_query_order_by_defaultcreated_at,
            request_query_order__defaultdesc,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class V2AccessTierGet(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def v2_access_tier_get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v2_access_tier_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v2_access_tier_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from banyanclient import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from banyanclient import schemas  # noqa: F401

from . import path

# query params
SerialnumberSchema = schemas.StrSchema
EmailSchema = schemas.StrSchema
SkipSchema = schemas.IntSchema
LimitSchema = schemas.IntSchema
NameSchema = schemas.StrSchema
OrderSchema = schemas.StrSchema
OrderBySchema = schemas.StrSchema
ExactEmailSchema = schemas.StrSchema
ExactSerialNumberSchema = schemas.StrSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'Serialnumber': typing.Union[SerialnumberSchema, str, ],
        'Email': typing.Union[EmailSchema, str, ],
        'Skip': typing.Union[SkipSchema, decimal.Decimal, int, ],
        'Limit': typing.Union[LimitSchema, decimal.Decimal, int, ],
        'Name': typing.Union[NameSchema, str, ],
        'Order': typing.Union[OrderSchema, str, ],
        'OrderBy': typing.Union[OrderBySchema, str, ],
        'exact_email': typing.Union[ExactEmailSchema, str, ],
        'exact_serial_number': typing.Union[ExactSerialNumberSchema, str, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_serialnumber = api_client.QueryParameter(
    name="Serialnumber",
    style=api_client.ParameterStyle.FORM,
    schema=SerialnumberSchema,
    explode=True,
)
request_query_email = api_client.QueryParameter(
    name="Email",
    style=api_client.ParameterStyle.FORM,
    schema=EmailSchema,
    explode=True,
)
request_query_skip = api_client.QueryParameter(
    name="Skip",
    style=api_client.ParameterStyle.FORM,
    schema=SkipSchema,
    explode=True,
)
request_query_limit = api_client.QueryParameter(
    name="Limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    explode=True,
)
request_query_name = api_client.QueryParameter(
    name="Name",
    style=api_client.ParameterStyle.FORM,
    schema=NameSchema,
    explode=True,
)
request_query_order = api_client.QueryParameter(
    name="Order",
    style=api_client.ParameterStyle.FORM,
    schema=OrderSchema,
    explode=True,
)
request_query_order_by = api_client.QueryParameter(
    name="OrderBy",
    style=api_client.ParameterStyle.FORM,
    schema=OrderBySchema,
    explode=True,
)
request_query_exact_email = api_client.QueryParameter(
    name="exact_email",
    style=api_client.ParameterStyle.FORM,
    schema=ExactEmailSchema,
    explode=True,
)
request_query_exact_serial_number = api_client.QueryParameter(
    name="exact_serial_number",
    style=api_client.ParameterStyle.FORM,
    schema=ExactSerialNumberSchema,
    explode=True,
)
_auth = [
    'bearerAuthToken',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            
            
            class endusers(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            
                            class properties:
                                Name = schemas.StrSchema
                                Email = schemas.StrSchema
                                Groups = schemas.StrSchema
                                
                                
                                class TrustData(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        
                                        class properties:
                                            EntityTrustscore = schemas.IntSchema
                                            OverrideTrustscore = schemas.IntSchema
                                            AccessTrustscore = schemas.IntSchema
                                            OverrideActive = schemas.StrSchema
                                            Level = schemas.StrSchema
                                            UpdatedAt = schemas.IntSchema
                                            Factors = schemas.IntSchema
                                            __annotations__ = {
                                                "EntityTrustscore": EntityTrustscore,
                                                "OverrideTrustscore": OverrideTrustscore,
                                                "AccessTrustscore": AccessTrustscore,
                                                "OverrideActive": OverrideActive,
                                                "Level": Level,
                                                "UpdatedAt": UpdatedAt,
                                                "Factors": Factors,
                                            }
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["EntityTrustscore"]) -> MetaOapg.properties.EntityTrustscore: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["OverrideTrustscore"]) -> MetaOapg.properties.OverrideTrustscore: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["AccessTrustscore"]) -> MetaOapg.properties.AccessTrustscore: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["OverrideActive"]) -> MetaOapg.properties.OverrideActive: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Level"]) -> MetaOapg.properties.Level: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["UpdatedAt"]) -> MetaOapg.properties.UpdatedAt: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Factors"]) -> MetaOapg.properties.Factors: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["EntityTrustscore", "OverrideTrustscore", "AccessTrustscore", "OverrideActive", "Level", "UpdatedAt", "Factors", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["EntityTrustscore"]) -> typing.Union[MetaOapg.properties.EntityTrustscore, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["OverrideTrustscore"]) -> typing.Union[MetaOapg.properties.OverrideTrustscore, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["AccessTrustscore"]) -> typing.Union[MetaOapg.properties.AccessTrustscore, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["OverrideActive"]) -> typing.Union[MetaOapg.properties.OverrideActive, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Level"]) -> typing.Union[MetaOapg.properties.Level, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["UpdatedAt"]) -> typing.Union[MetaOapg.properties.UpdatedAt, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Factors"]) -> typing.Union[MetaOapg.properties.Factors, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["EntityTrustscore", "OverrideTrustscore", "AccessTrustscore", "OverrideActive", "Level", "UpdatedAt", "Factors", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                        EntityTrustscore: typing.Union[MetaOapg.properties.EntityTrustscore, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        OverrideTrustscore: typing.Union[MetaOapg.properties.OverrideTrustscore, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        AccessTrustscore: typing.Union[MetaOapg.properties.AccessTrustscore, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        OverrideActive: typing.Union[MetaOapg.properties.OverrideActive, str, schemas.Unset] = schemas.unset,
                                        Level: typing.Union[MetaOapg.properties.Level, str, schemas.Unset] = schemas.unset,
                                        UpdatedAt: typing.Union[MetaOapg.properties.UpdatedAt, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        Factors: typing.Union[MetaOapg.properties.Factors, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'TrustData':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            EntityTrustscore=EntityTrustscore,
                                            OverrideTrustscore=OverrideTrustscore,
                                            AccessTrustscore=AccessTrustscore,
                                            OverrideActive=OverrideActive,
                                            Level=Level,
                                            UpdatedAt=UpdatedAt,
                                            Factors=Factors,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                                
                                
                                class Roles(
                                    schemas.ListSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        items = schemas.StrSchema
                                
                                    def __new__(
                                        cls,
                                        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                    ) -> 'Roles':
                                        return super().__new__(
                                            cls,
                                            arg,
                                            _configuration=_configuration,
                                        )
                                
                                    def __getitem__(self, i: int) -> MetaOapg.items:
                                        return super().__getitem__(i)
                                __annotations__ = {
                                    "Name": Name,
                                    "Email": Email,
                                    "Groups": Groups,
                                    "TrustData": TrustData,
                                    "Roles": Roles,
                                }
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["Name"]) -> MetaOapg.properties.Name: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["Email"]) -> MetaOapg.properties.Email: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["Groups"]) -> MetaOapg.properties.Groups: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["TrustData"]) -> MetaOapg.properties.TrustData: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["Roles"]) -> MetaOapg.properties.Roles: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["Name", "Email", "Groups", "TrustData", "Roles", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["Name"]) -> typing.Union[MetaOapg.properties.Name, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["Email"]) -> typing.Union[MetaOapg.properties.Email, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["Groups"]) -> typing.Union[MetaOapg.properties.Groups, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["TrustData"]) -> typing.Union[MetaOapg.properties.TrustData, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["Roles"]) -> typing.Union[MetaOapg.properties.Roles, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["Name", "Email", "Groups", "TrustData", "Roles", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *args: typing.Union[dict, frozendict.frozendict, ],
                            Name: typing.Union[MetaOapg.properties.Name, str, schemas.Unset] = schemas.unset,
                            Email: typing.Union[MetaOapg.properties.Email, str, schemas.Unset] = schemas.unset,
                            Groups: typing.Union[MetaOapg.properties.Groups, str, schemas.Unset] = schemas.unset,
                            TrustData: typing.Union[MetaOapg.properties.TrustData, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                            Roles: typing.Union[MetaOapg.properties.Roles, list, tuple, schemas.Unset] = schemas.unset,
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *args,
                                Name=Name,
                                Email=Email,
                                Groups=Groups,
                                TrustData=TrustData,
                                Roles=Roles,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'endusers':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            count = schemas.IntSchema
            __annotations__ = {
                "endusers": endusers,
                "count": count,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["endusers"]) -> MetaOapg.properties.endusers: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["count"]) -> MetaOapg.properties.count: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["endusers", "count", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["endusers"]) -> typing.Union[MetaOapg.properties.endusers, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["count"]) -> typing.Union[MetaOapg.properties.count, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["endusers", "count", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        endusers: typing.Union[MetaOapg.properties.endusers, list, tuple, schemas.Unset] = schemas.unset,
        count: typing.Union[MetaOapg.properties.count, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            endusers=endusers,
            count=count,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
)


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):

    def _v1_endusers_get_oapg(
        self: api_client.Api,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
        Get the End Users in an Organization
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_serialnumber,
            request_query_email,
            request_query_skip,
            request_query_limit,
            request_query_name,
            request_query_order,
            request_query_order_by,
            request_query_exact_email,
            request_query_exact_serial_number,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class V1EndusersGet(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def v1_endusers_get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_endusers_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_endusers_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

# flake8: noqa

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.0.0"

# import ApiClient
from banyanclient.api_client import ApiClient

# import Configuration
from banyanclient.configuration import Configuration

# import exceptions
from banyanclient.exceptions import OpenApiException
from banyanclient.exceptions import ApiAttributeError
from banyanclient.exceptions import ApiTypeError
from banyanclient.exceptions import ApiValueError
from banyanclient.exceptions import ApiKeyError
from banyanclient.exceptions import ApiException



import typing_extensions

from banyanclient.apis.tags import TagValues
from banyanclient.apis.tags.access_tier_api import AccessTierApi
from banyanclient.apis.tags.registered_service_api import RegisteredServiceApi
from banyanclient.apis.tags.api_key_api import ApiKeyApi
from banyanclient.apis.tags.audit_log_api import AuditLogApi
from banyanclient.apis.tags.bundle_api import BundleApi
from banyanclient.apis.tags.cloud_resource_api import CloudResourceApi
from banyanclient.apis.tags.cloud_resource_service_api import CloudResourceServiceApi
from banyanclient.apis.tags.device_api import DeviceApi
from banyanclient.apis.tags.enduser_api import EnduserApi
from banyanclient.apis.tags.security_role_api import SecurityRoleApi
from banyanclient.apis.tags.event_api import EventApi
from banyanclient.apis.tags.saasapp_api import SaasappApi
from banyanclient.apis.tags.satellite_api import SatelliteApi
from banyanclient.apis.tags.service_tunnel_api import ServiceTunnelApi
from banyanclient.apis.tags.security_policy_api import SecurityPolicyApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.ACCESS_TIER: AccessTierApi,
        TagValues.REGISTERED_SERVICE: RegisteredServiceApi,
        TagValues.API_KEY: ApiKeyApi,
        TagValues.AUDIT_LOG: AuditLogApi,
        TagValues.BUNDLE: BundleApi,
        TagValues.CLOUD_RESOURCE: CloudResourceApi,
        TagValues.CLOUD_RESOURCE_SERVICE: CloudResourceServiceApi,
        TagValues.DEVICE: DeviceApi,
        TagValues.ENDUSER: EnduserApi,
        TagValues.SECURITY_ROLE: SecurityRoleApi,
        TagValues.EVENT: EventApi,
        TagValues.SAASAPP: SaasappApi,
        TagValues.SATELLITE: SatelliteApi,
        TagValues.SERVICE_TUNNEL: ServiceTunnelApi,
        TagValues.SECURITY_POLICY: SecurityPolicyApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.ACCESS_TIER: AccessTierApi,
        TagValues.REGISTERED_SERVICE: RegisteredServiceApi,
        TagValues.API_KEY: ApiKeyApi,
        TagValues.AUDIT_LOG: AuditLogApi,
        TagValues.BUNDLE: BundleApi,
        TagValues.CLOUD_RESOURCE: CloudResourceApi,
        TagValues.CLOUD_RESOURCE_SERVICE: CloudResourceServiceApi,
        TagValues.DEVICE: DeviceApi,
        TagValues.ENDUSER: EnduserApi,
        TagValues.SECURITY_ROLE: SecurityRoleApi,
        TagValues.EVENT: EventApi,
        TagValues.SAASAPP: SaasappApi,
        TagValues.SATELLITE: SatelliteApi,
        TagValues.SERVICE_TUNNEL: ServiceTunnelApi,
        TagValues.SECURITY_POLICY: SecurityPolicyApi,
    }
)



import typing_extensions

from banyanclient.paths import PathValues
from banyanclient.apis.paths.v1_enable_registered_service import V1EnableRegisteredService
from banyanclient.apis.paths.v1_services_stats import V1ServicesStats
from banyanclient.apis.paths.v1_service_connection_test import V1ServiceConnectionTest
from banyanclient.apis.paths.v1_insert_registered_service import V1InsertRegisteredService
from banyanclient.apis.paths.v2_access_tier_id_registered_services import V2AccessTierIdRegisteredServices
from banyanclient.apis.paths.v1_registered_services import V1RegisteredServices
from banyanclient.apis.paths.v1_delete_registered_service import V1DeleteRegisteredService
from banyanclient.apis.paths.v1_disable_registered_service import V1DisableRegisteredService
from banyanclient.apis.paths.v2_bundle_bundle_id import V2BundleBundleId
from banyanclient.apis.paths.v2_bundle import V2Bundle
from banyanclient.apis.paths.v2_bundle_bundle_id_service import V2BundleBundleIdService
from banyanclient.apis.paths.v2_bundle_bundle_id_service_service_id import V2BundleBundleIdServiceServiceId
from banyanclient.apis.paths.v2_service_tunnel import V2ServiceTunnel
from banyanclient.apis.paths.service_tunnel_id_security_policy_policy_id import ServiceTunnelIdSecurityPolicyPolicyId
from banyanclient.apis.paths.service_tunnel_id_security_policy import ServiceTunnelIdSecurityPolicy
from banyanclient.apis.paths.v2_service_tunnel_id import V2ServiceTunnelId
from banyanclient.apis.paths.v1_insert_saasapp import V1InsertSaasapp
from banyanclient.apis.paths.v1_policy_policy_id_attachment import V1PolicyPolicyIDAttachment
from banyanclient.apis.paths.v1_security_policies import V1SecurityPolicies
from banyanclient.apis.paths.v1_security_attach_policies import V1SecurityAttachPolicies
from banyanclient.apis.paths.v1_policies_stats import V1PoliciesStats
from banyanclient.apis.paths.v1_policy_attachment_attached_to_type_attached_to_id import V1PolicyAttachmentAttachedToTypeAttachedToID
from banyanclient.apis.paths.v1_policy_attachment_attached_to_type import V1PolicyAttachmentAttachedToType
from banyanclient.apis.paths.v1_delete_security_policy import V1DeleteSecurityPolicy
from banyanclient.apis.paths.v1_insert_security_attach_policy import V1InsertSecurityAttachPolicy
from banyanclient.apis.paths.v1_policy_attachment import V1PolicyAttachment
from banyanclient.apis.paths.v1_delete_security_attach_policy import V1DeleteSecurityAttachPolicy
from banyanclient.apis.paths.v1_insert_security_policy import V1InsertSecurityPolicy
from banyanclient.apis.paths.v1_securityroles_stats import V1SecurityrolesStats
from banyanclient.apis.paths.v1_disable_security_role import V1DisableSecurityRole
from banyanclient.apis.paths.v1_insert_security_role import V1InsertSecurityRole
from banyanclient.apis.paths.v1_enable_security_role import V1EnableSecurityRole
from banyanclient.apis.paths.v1_security_roles_enduser_devices import V1SecurityRolesEnduserDevices
from banyanclient.apis.paths.v1_delete_security_role import V1DeleteSecurityRole
from banyanclient.apis.paths.v1_security_roles import V1SecurityRoles
from banyanclient.apis.paths.v1_unregistered_device_endusers_csv import V1UnregisteredDeviceEndusersCsv
from banyanclient.apis.paths.v1_endusers_stats import V1EndusersStats
from banyanclient.apis.paths.v2_endusers import V2Endusers
from banyanclient.apis.paths.v1_mdm_insert_devices import V1MdmInsertDevices
from banyanclient.apis.paths.v2_enduser_groups import V2EnduserGroups
from banyanclient.apis.paths.v1_endusers import V1Endusers
from banyanclient.apis.paths.v1_enduser_devices_data import V1EnduserDevicesData
from banyanclient.apis.paths.v2_enduser import V2Enduser
from banyanclient.apis.paths.v1_endusers_csv import V1EndusersCsv
from banyanclient.apis.paths.v2_enduser_id import V2EnduserId
from banyanclient.apis.paths.v1_delete_device import V1DeleteDevice
from banyanclient.apis.paths.v1_send_device_notification import V1SendDeviceNotification
from banyanclient.apis.paths.v2_devices_csv import V2DevicesCsv
from banyanclient.apis.paths.v2_devices import V2Devices
from banyanclient.apis.paths.v1_enduser_devices import V1EnduserDevices
from banyanclient.apis.paths.v1_mdm_device_info import V1MdmDeviceInfo
from banyanclient.apis.paths.v1_device_id_token import V1DeviceIdToken
from banyanclient.apis.paths.v1_mdm_update_device import V1MdmUpdateDevice
from banyanclient.apis.paths.v1_devices_stats import V1DevicesStats
from banyanclient.apis.paths.v1_devices import V1Devices
from banyanclient.apis.paths.v1_events import V1Events
from banyanclient.apis.paths.v2_event_daily_counts import V2EventDailyCounts
from banyanclient.apis.paths.v1_event_types import V1EventTypes
from banyanclient.apis.paths.v1_events_feed import V1EventsFeed
from banyanclient.apis.paths.v1_events_count import V1EventsCount
from banyanclient.apis.paths.v1_audit_logs import V1AuditLogs
from banyanclient.apis.paths.v2_access_tier_id import V2AccessTierId
from banyanclient.apis.paths.v1_access_tiers_stats import V1AccessTiersStats
from banyanclient.apis.paths.v2_access_tier import V2AccessTier
from banyanclient.apis.paths.v1_one_click_support_bundle import V1OneClickSupportBundle
from banyanclient.apis.paths.v1_service_hostname_mapping import V1ServiceHostnameMapping
from banyanclient.apis.paths.v2_access_tier_access_tier_id_tunnel_config_tunnel_config_id import V2AccessTierAccessTierIdTunnelConfigTunnelConfigId
from banyanclient.apis.paths.v2_satellite import V2Satellite
from banyanclient.apis.paths.v2_satellite_id import V2SatelliteId
from banyanclient.apis.paths.v2_connector_stats import V2ConnectorStats
from banyanclient.apis.paths.v2_cloud_resource_id import V2CloudResourceId
from banyanclient.apis.paths.v2_cloud_resource_service_id import V2CloudResourceServiceId
from banyanclient.apis.paths.v2_cloud_resource_service import V2CloudResourceService
from banyanclient.apis.paths.v2_api_key_id import V2ApiKeyId
from banyanclient.apis.paths.v2_api_key_scope import V2ApiKeyScope
from banyanclient.apis.paths.v2_api_key import V2ApiKey

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.V1_ENABLE_REGISTERED_SERVICE: V1EnableRegisteredService,
        PathValues.V1_SERVICES_STATS: V1ServicesStats,
        PathValues.V1_SERVICE_CONNECTION_TEST: V1ServiceConnectionTest,
        PathValues.V1_INSERT_REGISTERED_SERVICE: V1InsertRegisteredService,
        PathValues.V2_ACCESS_TIER_ID_REGISTERED_SERVICES: V2AccessTierIdRegisteredServices,
        PathValues.V1_REGISTERED_SERVICES: V1RegisteredServices,
        PathValues.V1_DELETE_REGISTERED_SERVICE: V1DeleteRegisteredService,
        PathValues.V1_DISABLE_REGISTERED_SERVICE: V1DisableRegisteredService,
        PathValues.V2_BUNDLE_BUNDLE_ID: V2BundleBundleId,
        PathValues.V2_BUNDLE: V2Bundle,
        PathValues.V2_BUNDLE_BUNDLE_ID_SERVICE: V2BundleBundleIdService,
        PathValues.V2_BUNDLE_BUNDLE_ID_SERVICE_SERVICE_ID: V2BundleBundleIdServiceServiceId,
        PathValues.V2_SERVICE_TUNNEL: V2ServiceTunnel,
        PathValues.SERVICE_TUNNEL_ID_SECURITY_POLICY_POLICY_ID: ServiceTunnelIdSecurityPolicyPolicyId,
        PathValues.SERVICE_TUNNEL_ID_SECURITY_POLICY: ServiceTunnelIdSecurityPolicy,
        PathValues.V2_SERVICE_TUNNEL_ID: V2ServiceTunnelId,
        PathValues.V1_INSERT_SAASAPP: V1InsertSaasapp,
        PathValues.V1_POLICY_POLICY_ID_ATTACHMENT: V1PolicyPolicyIDAttachment,
        PathValues.V1_SECURITY_POLICIES: V1SecurityPolicies,
        PathValues.V1_SECURITY_ATTACH_POLICIES: V1SecurityAttachPolicies,
        PathValues.V1_POLICIES_STATS: V1PoliciesStats,
        PathValues.V1_POLICY_ATTACHMENT_ATTACHED_TO_TYPE_ATTACHED_TO_ID: V1PolicyAttachmentAttachedToTypeAttachedToID,
        PathValues.V1_POLICY_ATTACHMENT_ATTACHED_TO_TYPE: V1PolicyAttachmentAttachedToType,
        PathValues.V1_DELETE_SECURITY_POLICY: V1DeleteSecurityPolicy,
        PathValues.V1_INSERT_SECURITY_ATTACH_POLICY: V1InsertSecurityAttachPolicy,
        PathValues.V1_POLICY_ATTACHMENT: V1PolicyAttachment,
        PathValues.V1_DELETE_SECURITY_ATTACH_POLICY: V1DeleteSecurityAttachPolicy,
        PathValues.V1_INSERT_SECURITY_POLICY: V1InsertSecurityPolicy,
        PathValues.V1_SECURITYROLES_STATS: V1SecurityrolesStats,
        PathValues.V1_DISABLE_SECURITY_ROLE: V1DisableSecurityRole,
        PathValues.V1_INSERT_SECURITY_ROLE: V1InsertSecurityRole,
        PathValues.V1_ENABLE_SECURITY_ROLE: V1EnableSecurityRole,
        PathValues.V1_SECURITY_ROLES_ENDUSER_DEVICES: V1SecurityRolesEnduserDevices,
        PathValues.V1_DELETE_SECURITY_ROLE: V1DeleteSecurityRole,
        PathValues.V1_SECURITY_ROLES: V1SecurityRoles,
        PathValues.V1_UNREGISTERED_DEVICE_ENDUSERS_CSV: V1UnregisteredDeviceEndusersCsv,
        PathValues.V1_ENDUSERS_STATS: V1EndusersStats,
        PathValues.V2_ENDUSERS: V2Endusers,
        PathValues.V1_MDM_INSERT_DEVICES: V1MdmInsertDevices,
        PathValues.V2_ENDUSER_GROUPS: V2EnduserGroups,
        PathValues.V1_ENDUSERS: V1Endusers,
        PathValues.V1_ENDUSER_DEVICES_DATA: V1EnduserDevicesData,
        PathValues.V2_ENDUSER: V2Enduser,
        PathValues.V1_ENDUSERS_CSV: V1EndusersCsv,
        PathValues.V2_ENDUSER_ID: V2EnduserId,
        PathValues.V1_DELETE_DEVICE: V1DeleteDevice,
        PathValues.V1_SEND_DEVICE_NOTIFICATION: V1SendDeviceNotification,
        PathValues.V2_DEVICES_CSV: V2DevicesCsv,
        PathValues.V2_DEVICES: V2Devices,
        PathValues.V1_ENDUSER_DEVICES: V1EnduserDevices,
        PathValues.V1_MDM_DEVICE_INFO: V1MdmDeviceInfo,
        PathValues.V1_DEVICE_ID_TOKEN: V1DeviceIdToken,
        PathValues.V1_MDM_UPDATE_DEVICE: V1MdmUpdateDevice,
        PathValues.V1_DEVICES_STATS: V1DevicesStats,
        PathValues.V1_DEVICES: V1Devices,
        PathValues.V1_EVENTS: V1Events,
        PathValues.V2_EVENT_DAILY_COUNTS: V2EventDailyCounts,
        PathValues.V1_EVENT_TYPES: V1EventTypes,
        PathValues.V1_EVENTS_FEED: V1EventsFeed,
        PathValues.V1_EVENTS_COUNT: V1EventsCount,
        PathValues.V1_AUDIT_LOGS: V1AuditLogs,
        PathValues.V2_ACCESS_TIER_ID: V2AccessTierId,
        PathValues.V1_ACCESS_TIERS_STATS: V1AccessTiersStats,
        PathValues.V2_ACCESS_TIER: V2AccessTier,
        PathValues.V1_ONE_CLICK_SUPPORT_BUNDLE: V1OneClickSupportBundle,
        PathValues.V1_SERVICE_HOSTNAME_MAPPING: V1ServiceHostnameMapping,
        PathValues.V2_ACCESS_TIER_ACCESS_TIER_ID_TUNNEL_CONFIG_TUNNEL_CONFIG_ID: V2AccessTierAccessTierIdTunnelConfigTunnelConfigId,
        PathValues.V2_SATELLITE: V2Satellite,
        PathValues.V2_SATELLITE_ID: V2SatelliteId,
        PathValues.V2_CONNECTOR_STATS: V2ConnectorStats,
        PathValues.V2_CLOUD_RESOURCE_ID: V2CloudResourceId,
        PathValues.V2_CLOUD_RESOURCE_SERVICE_ID: V2CloudResourceServiceId,
        PathValues.V2_CLOUD_RESOURCE_SERVICE: V2CloudResourceService,
        PathValues.V2_API_KEY_ID: V2ApiKeyId,
        PathValues.V2_API_KEY_SCOPE: V2ApiKeyScope,
        PathValues.V2_API_KEY: V2ApiKey,
    }
)

path_to_api = PathToApi(
    {
        PathValues.V1_ENABLE_REGISTERED_SERVICE: V1EnableRegisteredService,
        PathValues.V1_SERVICES_STATS: V1ServicesStats,
        PathValues.V1_SERVICE_CONNECTION_TEST: V1ServiceConnectionTest,
        PathValues.V1_INSERT_REGISTERED_SERVICE: V1InsertRegisteredService,
        PathValues.V2_ACCESS_TIER_ID_REGISTERED_SERVICES: V2AccessTierIdRegisteredServices,
        PathValues.V1_REGISTERED_SERVICES: V1RegisteredServices,
        PathValues.V1_DELETE_REGISTERED_SERVICE: V1DeleteRegisteredService,
        PathValues.V1_DISABLE_REGISTERED_SERVICE: V1DisableRegisteredService,
        PathValues.V2_BUNDLE_BUNDLE_ID: V2BundleBundleId,
        PathValues.V2_BUNDLE: V2Bundle,
        PathValues.V2_BUNDLE_BUNDLE_ID_SERVICE: V2BundleBundleIdService,
        PathValues.V2_BUNDLE_BUNDLE_ID_SERVICE_SERVICE_ID: V2BundleBundleIdServiceServiceId,
        PathValues.V2_SERVICE_TUNNEL: V2ServiceTunnel,
        PathValues.SERVICE_TUNNEL_ID_SECURITY_POLICY_POLICY_ID: ServiceTunnelIdSecurityPolicyPolicyId,
        PathValues.SERVICE_TUNNEL_ID_SECURITY_POLICY: ServiceTunnelIdSecurityPolicy,
        PathValues.V2_SERVICE_TUNNEL_ID: V2ServiceTunnelId,
        PathValues.V1_INSERT_SAASAPP: V1InsertSaasapp,
        PathValues.V1_POLICY_POLICY_ID_ATTACHMENT: V1PolicyPolicyIDAttachment,
        PathValues.V1_SECURITY_POLICIES: V1SecurityPolicies,
        PathValues.V1_SECURITY_ATTACH_POLICIES: V1SecurityAttachPolicies,
        PathValues.V1_POLICIES_STATS: V1PoliciesStats,
        PathValues.V1_POLICY_ATTACHMENT_ATTACHED_TO_TYPE_ATTACHED_TO_ID: V1PolicyAttachmentAttachedToTypeAttachedToID,
        PathValues.V1_POLICY_ATTACHMENT_ATTACHED_TO_TYPE: V1PolicyAttachmentAttachedToType,
        PathValues.V1_DELETE_SECURITY_POLICY: V1DeleteSecurityPolicy,
        PathValues.V1_INSERT_SECURITY_ATTACH_POLICY: V1InsertSecurityAttachPolicy,
        PathValues.V1_POLICY_ATTACHMENT: V1PolicyAttachment,
        PathValues.V1_DELETE_SECURITY_ATTACH_POLICY: V1DeleteSecurityAttachPolicy,
        PathValues.V1_INSERT_SECURITY_POLICY: V1InsertSecurityPolicy,
        PathValues.V1_SECURITYROLES_STATS: V1SecurityrolesStats,
        PathValues.V1_DISABLE_SECURITY_ROLE: V1DisableSecurityRole,
        PathValues.V1_INSERT_SECURITY_ROLE: V1InsertSecurityRole,
        PathValues.V1_ENABLE_SECURITY_ROLE: V1EnableSecurityRole,
        PathValues.V1_SECURITY_ROLES_ENDUSER_DEVICES: V1SecurityRolesEnduserDevices,
        PathValues.V1_DELETE_SECURITY_ROLE: V1DeleteSecurityRole,
        PathValues.V1_SECURITY_ROLES: V1SecurityRoles,
        PathValues.V1_UNREGISTERED_DEVICE_ENDUSERS_CSV: V1UnregisteredDeviceEndusersCsv,
        PathValues.V1_ENDUSERS_STATS: V1EndusersStats,
        PathValues.V2_ENDUSERS: V2Endusers,
        PathValues.V1_MDM_INSERT_DEVICES: V1MdmInsertDevices,
        PathValues.V2_ENDUSER_GROUPS: V2EnduserGroups,
        PathValues.V1_ENDUSERS: V1Endusers,
        PathValues.V1_ENDUSER_DEVICES_DATA: V1EnduserDevicesData,
        PathValues.V2_ENDUSER: V2Enduser,
        PathValues.V1_ENDUSERS_CSV: V1EndusersCsv,
        PathValues.V2_ENDUSER_ID: V2EnduserId,
        PathValues.V1_DELETE_DEVICE: V1DeleteDevice,
        PathValues.V1_SEND_DEVICE_NOTIFICATION: V1SendDeviceNotification,
        PathValues.V2_DEVICES_CSV: V2DevicesCsv,
        PathValues.V2_DEVICES: V2Devices,
        PathValues.V1_ENDUSER_DEVICES: V1EnduserDevices,
        PathValues.V1_MDM_DEVICE_INFO: V1MdmDeviceInfo,
        PathValues.V1_DEVICE_ID_TOKEN: V1DeviceIdToken,
        PathValues.V1_MDM_UPDATE_DEVICE: V1MdmUpdateDevice,
        PathValues.V1_DEVICES_STATS: V1DevicesStats,
        PathValues.V1_DEVICES: V1Devices,
        PathValues.V1_EVENTS: V1Events,
        PathValues.V2_EVENT_DAILY_COUNTS: V2EventDailyCounts,
        PathValues.V1_EVENT_TYPES: V1EventTypes,
        PathValues.V1_EVENTS_FEED: V1EventsFeed,
        PathValues.V1_EVENTS_COUNT: V1EventsCount,
        PathValues.V1_AUDIT_LOGS: V1AuditLogs,
        PathValues.V2_ACCESS_TIER_ID: V2AccessTierId,
        PathValues.V1_ACCESS_TIERS_STATS: V1AccessTiersStats,
        PathValues.V2_ACCESS_TIER: V2AccessTier,
        PathValues.V1_ONE_CLICK_SUPPORT_BUNDLE: V1OneClickSupportBundle,
        PathValues.V1_SERVICE_HOSTNAME_MAPPING: V1ServiceHostnameMapping,
        PathValues.V2_ACCESS_TIER_ACCESS_TIER_ID_TUNNEL_CONFIG_TUNNEL_CONFIG_ID: V2AccessTierAccessTierIdTunnelConfigTunnelConfigId,
        PathValues.V2_SATELLITE: V2Satellite,
        PathValues.V2_SATELLITE_ID: V2SatelliteId,
        PathValues.V2_CONNECTOR_STATS: V2ConnectorStats,
        PathValues.V2_CLOUD_RESOURCE_ID: V2CloudResourceId,
        PathValues.V2_CLOUD_RESOURCE_SERVICE_ID: V2CloudResourceServiceId,
        PathValues.V2_CLOUD_RESOURCE_SERVICE: V2CloudResourceService,
        PathValues.V2_API_KEY_ID: V2ApiKeyId,
        PathValues.V2_API_KEY_SCOPE: V2ApiKeyScope,
        PathValues.V2_API_KEY: V2ApiKey,
    }
)
